import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

const originalPush = Router.prototype.push;
Router.prototype.push = function (location) {
    originalPush.call(this, location).catch((err) => err);
};
const originalReplace = Router.prototype.replace;
Router.prototype.replace = function (location) {
    originalReplace.call(this, location).catch((err) => err);
};

/* AppLayout */
import AppLayout from "@/layout/app/index.vue";

/* MainDefaultLayout */
import MainDefaultLayout from "@/layout/main/default/index.vue";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * allRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const allRoutes = [
    {
        path: "/404",
        component: () => import("@/views/404.vue"),
        hidden: true,
    },

    {
        path: "/",
        redirect: "/dygl/bjhd",
    },
    {
        path: "/dygl",
        name: 'dygl',
        component: AppLayout,
        meta: {title: "德育管理", icon: "el-icon-document"},
        redirect: '/dygl/bjhd',
        children: [{
            path: "/dygl/bjhd",
            name: "dygl_bjhd",
            component: () => import("@/views/dygl/bjhd/index.vue"),
            meta: {title: "班级活动"},

        },{
            path: "cjxt",
            name: "dygl_cjxt",
            component: () => import("@/views/dygl/cjxt/index.vue"),
            meta: {title: "晨检系统"},
        },{
            path: "xshjgl",
            name: "dygl_xshjgl",
            component: () => import("@/views/dygl/xshjgl/index.vue"),
            meta: {title: "学生获奖管理"},
        },{
            path: "xsxjk",
            name: "dygl_xsxjk",
            component: () => import("@/views/dygl/xsxjk/index.vue"),
            meta: {title: "学生学籍卡"},
        },{
            path: "bjzzpb",
            name: "dygl_bjzzpb",
            component: () => import("@/views/dygl/bjzzpb/index.vue"),
            meta: {title: "班级值周评比"},
        },{
            path: "xsczda",
            name: "dygl_xsczda",
            component: () => import("@/views/dygl/xsczda/index.vue"),
            meta: {title: "学生成长档案"},
        },{
            path: "wypj",
            name: "dygl_wypj",
            component: () => import("@/views/dygl/wypj/index.vue"),
            meta: {title: "五育评价"},
        },{
            path: "fxxt",
            name: "dygl_fxxt",
            component: () => import("@/views/dygl/fxxt/index.vue"),
            meta: {title: "放学系统"},
        }]
    },
    // 404 page must be placed at the end !!!
    {path: "*", redirect: "/404", hidden: true},
];

function hasPermission(route, role) {
    if (Array.isArray(route?.meta?.roles)) {
        return route.meta.roles.includes(role);
    } else {
        return true;
    }
}

function handleFilterRoutes(routes, role) {
    const res = [];
    routes.forEach((route) => {
        const tmp = {...route};
        if (hasPermission(tmp, role)) {
            if (tmp.children) {
                tmp.children = handleFilterRoutes(tmp.children, role);
            }
            res.push(tmp);
        }
    });
    return res;
}

import {user} from "@/stores/user";

// var filterRoutes;
// const ifPower = user.power;
// var announceMark = ifPower.announce;
// if (announceMark == 1) {
//     //设定了权限;
//     var aa = filterNewRoutes(allRoutes, ifPower);
//
//     filterRoutes = handleFilterRoutes(aa, user.roleName)
//     console.log(filterRoutes, "9999")
// } else {
//     //没有设定权限
//     filterRoutes = handleFilterRoutes(allRoutes, user.roleName);
// }

// var filterRoutes = handleFilterRoutes(allRoutes, user.roleName);

function filterNewRoutes(allRoutes, ifPower) {
    var temp_routesArr = [];
    allRoutes.forEach((item) => {
        const tmp = {...item};
        if (item.name == "mhgl") {
            delete item.meta.roles;
            if (item.children) {
                item.children.forEach((itemSec) => {
                    //将活动公告，通知公告的roles去除
                    if (itemSec.path == "hdgg" || itemSec.path == "tzgg") {
                        delete itemSec.meta.roles;
                    }
                });
            }
        }
        temp_routesArr.push(tmp);
    });
    return temp_routesArr;
}

const createRouter = () =>
    new Router({
        // mode: 'history', // require service support
        scrollBehavior: () => ({y: 0}),
        routes: allRoutes,
    });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter();
    router.matcher = newRouter.matcher; // reset router
}

export default router;

/* 
=====================================================================================
=====================================================================================
*/

import getPageTitle from "@/utils/get-page-title";

router.beforeEach(async (to, from, next) => {
    document.title = getPageTitle(to.meta.title);
    console.groupCollapsed(
        `router ${from.meta.title || "新进入"} => ${to.meta.title}`
    );
    console.log("from :>> ", from);
    console.log("to :>> ", to);
    console.groupEnd();
    next();
});
