import axios from 'axios'
import { Message } from 'element-ui'

import { useUserStore } from '@/stores/user'
const { token } = useUserStore()

const service = axios.create({
  baseURL: window.globalVariables.api,
  method: 'post',
  timeout: 60000,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  },
})

service.interceptors.request.use(
  (config) => {
    // do something before request is sent

    config.data = Object.assign(
      {
        token,
        site: 'qqyxt',
        client: 'web',
        api: 'json',
        // from: 'backend',
      },
      config.data || {}
    )
    if (config.method === 'get') {
      config.params = Object.assign(
        {
          token,
        },
        config.params || {}
      )
    }
    // 短时间多个请求会冲突
    // console.groupCollapsed('axios: ' + config.url)
    // console.log('request', config.data)
    return config
  },
  (error) => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  (response, c) => {
    const { code, msg } = response.data
    if (code !== '1') {
      Message.error(msg)
    }
    // console.log('response', response.data)
    // console.groupEnd()
    return response.data
  },
  (error) => {
    console.error('err' + error) // for debug
    return Promise.reject(error)
  }
)

// 上传
export const request = axios.create({
  baseURL: window.globalVariables.api,
  method: 'post',
  timeout: 5000,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  },
})
request.interceptors.response.use(
  (response) => {
    const { code, msg } = response.data
    if (code !== '1') {
      Message.error(msg)
    }
    return response.data
  },
  (error) => {
    console.log('err' + error) // for debug
    return Promise.reject(error)
  }
)

export default service
